@@ -11,7 +11,7 @@ pub fn get() -> Option<Info> {
 
     let version = match release.version.as_deref() {
         Some("rolling") => Version::Rolling(None),
-        Some(v) => Version::Custom(v.to_owned()),
+        Some(v) => Version::from_string(v.to_owned()),
         None => Version::Unknown,
     };
 
@@ -20,17 +20,21 @@ pub fn get() -> Option<Info> {
         Some("Amazon") | Some("AmazonAMI") => Type::Amazon,
         Some("Arch") => Type::Arch,
         Some("Artix") => Type::Artix,
+        Some("cachyos") => Type::CachyOS,
         Some("CentOS") => Type::CentOS,
         Some("Debian") => Type::Debian,
         Some("EndeavourOS") => Type::EndeavourOS,
         Some("Fedora") | Some("Fedora Linux") => Type::Fedora,
         Some("Garuda") => Type::Garuda,
         Some("Gentoo") => Type::Gentoo,
+        Some("Kali") => Type::Kali,
         Some("Linuxmint") => Type::Mint,
         Some("MaboxLinux") => Type::Mabox,
         Some("ManjaroLinux") => Type::Manjaro,
         Some("Mariner") => Type::Mariner,
         Some("NixOS") => Type::NixOS,
+        Some("NobaraLinux") => Type::Nobara,
+        Some("Uos") => Type::Uos,
         Some("OpenCloudOS") => Type::OpenCloudOS,
         Some("openEuler") => Type::openEuler,
         Some("openSUSE") => Type::openSUSE,
@@ -41,6 +45,8 @@ pub fn get() -> Option<Info> {
         Some("Solus") => Type::Solus,
         Some("SUSE") => Type::SUSE,
         Some("Ubuntu") => Type::Ubuntu,
+        Some("UltramarineLinux") => Type::Ultramarine,
+        Some("VoidLinux") => Type::Void,
         _ => Type::Linux,
     };
 
@@ -145,6 +151,14 @@ mod tests {
         assert_eq!(parse_results.codename, Some("TwentySix".to_string()));
     }
 
+    #[test]
+    fn kali_2023_2() {
+        let parse_results = parse(kali_2023_2_file());
+        assert_eq!(parse_results.distribution, Some("Kali".to_string()));
+        assert_eq!(parse_results.version, Some("2023.2".to_string()));
+        assert_eq!(parse_results.codename, Some("kali-rolling".to_string()));
+    }
+
     #[test]
     fn ubuntu() {
         let parse_results = parse(ubuntu_file());
@@ -172,6 +186,22 @@ mod tests {
         assert_eq!(parse_results.codename, Some("okapi".to_string()));
     }
 
+    #[test]
+    fn nobara() {
+        let parse_results = parse(nobara_file());
+        assert_eq!(parse_results.distribution, Some("NobaraLinux".to_string()));
+        assert_eq!(parse_results.version, Some("39".to_string()));
+        assert_eq!(parse_results.codename, None);
+    }
+
+    #[test]
+    fn uos() {
+        let parse_results = parse(uos_file());
+        assert_eq!(parse_results.distribution, Some("uos".to_string()));
+        assert_eq!(parse_results.version, Some("20".to_string()));
+        assert_eq!(parse_results.codename, Some("eagle".to_string()));
+    }
+
     #[test]
     fn amazon1() {
         let parse_results = parse(amazon1_file());
@@ -301,6 +331,24 @@ mod tests {
         assert_eq!(parse_results.codename, None);
     }
 
+    #[test]
+    fn ultramarine() {
+        let parse_results = parse(ultramarine_file());
+        assert_eq!(
+            parse_results.distribution,
+            Some("UltramarineLinux".to_string())
+        );
+        assert_eq!(parse_results.version, Some("39".to_string()));
+        assert_eq!(parse_results.codename, Some("kuma".to_string()));
+    }
+
+    #[test]
+    fn void_linux() {
+        let parse_results = parse(void_file());
+        assert_eq!(parse_results.distribution, Some("Void".to_string()));
+        assert_eq!(parse_results.version, Some("rolling".to_string()));
+    }
+
     #[test]
     fn raspbian() {
         let parse_results = parse(raspberry_os_file());
@@ -309,6 +357,13 @@ mod tests {
         assert_eq!(parse_results.codename, None);
     }
 
+    #[test]
+    fn cachyos() {
+        let parse_results = parse(cachyos_file());
+        assert_eq!(parse_results.distribution, Some("cachyos".to_string()));
+        assert_eq!(parse_results.version, Some("rolling".to_string()));
+    }
+
     fn file() -> &'static str {
         "\nDistributor ID:	Debian\n\
          Description:	Debian GNU/Linux 7.8 (wheezy)\n\
@@ -349,6 +404,14 @@ mod tests {
          "
     }
 
+    fn kali_2023_2_file() -> &'static str {
+        "\nDistributor ID: Kali\n\
+         Description:    Kali GNU/Linux Rolling\n\
+         Release:        2023.2\n\
+         Codename:       kali-rolling\n\
+         "
+    }
+
     fn ubuntu_file() -> &'static str {
         "Distributor ID: Ubuntu\n\
          Description:    Ubuntu 16.04.5 LTS\n\
@@ -370,6 +433,23 @@ mod tests {
          Codename:       okapi"
     }
 
+    fn nobara_file() -> &'static str {
+        "LSB Version:	n/a\n\
+        Distributor ID:	NobaraLinux\n\
+        Description:	Nobara Linux 39 (KDE Plasma)\n\
+        Release:	39\n\
+        Codename:	n/a\n\
+        "
+    }
+
+    fn uos_file() -> &'static str {
+        "Distributor ID: uos\n\
+         Description:	 UnionTech OS 20\n\
+         Release:	     20\n\
+         Codename:	     eagle\n\
+         "
+    }
+
     // Amazon Linux 1 uses a separate Distributor ID and Release format from Amazon Linux 2
     fn amazon1_file() -> &'static str {
         "LSB Version:	:base-4.0-amd64:base-4.0-noarch:core-4.0-amd64:core-4.0-noarch\n\
@@ -515,4 +595,30 @@ mod tests {
         Codename:	n/a\n\
         "
     }
+
+    fn ultramarine_file() -> &'static str {
+        "LSB Version:    n/a\n\
+        Distributor ID: UltramarineLinux\n\
+        Description:    Ultramarine Linux 39 (Kuma)\n\
+        Release:        39\n\
+        Codename:       kuma\n\
+        "
+    }
+
+    fn void_file() -> &'static str {
+        "LSB Version:        n/a\n\
+          Distributor ID:        Void\n\
+          Description:        Void Linux\n\
+          Release:        rolling\n\
+          Codename:        n/a\n\
+          "
+    }
+
+    fn cachyos_file() -> &'static str {
+        "Distributor ID: cachyos\n\
+         Description:	 CachyOS\n\
+         Release:	     rolling\n\
+         Codename:	     n/a\n\
+         "
+    }
 }
